# Puretalk-TTS

## Installation

To install the necessary dependencies, run the following command:

```sh
make install
```
This will install poetry and the required dependencies for the project.  

## Running the Script
To run the script, use the following command:
```angular2html
make run
```
You will be prompted to enter the text and voice ID. The script will then execute with the provided inputs.

install: Installs poetry and the project dependencies.
run: Prompts for text and voice ID.